@@ -1,4 +1,4 @@
-from models.chat import Chat
+from telebotify.models.chat import Chat
 from telebotify.models.jsonable import Jsonable
 from telebotify.models.user import User
 
